import React, { useState, useEffect, useRef } from 'react'
import SiteModal from '@/components/Modal/SiteModa';
import { Form, Input, notification, Select, Checkbox } from 'antd'
import BaseForm from '@/components/BaseForm/index';
import { Switch } from 'react-router';
import { iteratee } from 'lodash';
import styles from './EditModal.less';
import v from 'voca';
import VisibleRoleModal from './RolseSelect/VisibleRoleModal'
import VisibleIISAgentConfig from './IISAgentConfig/VisibleIISAgentConfig'
const { Item } = Form;

const EditModal = props => {


    const [form] = Form.useForm();
    const [loading, setLoading] = useState(false);
    const [isStart, setIsStart] = useState(false);
    const [currentTrench, setCurrentTrench] = useState({
        isMessageShow: false,
        isAPPShow: false,
        isWEBShow: false,
        isWXShow: false
    })
    const formEntity = useRef(null);
    const plainOptions = ['APP', '微信', 'WEB', '短信'];

    const onSubmit = () => {
        console.log(form.getFieldValue()) 
    }
    const operateProject = () => {

    }
    const onTypeChange = (value) => {
        console.log(value)
        setCurrentTrench({
            isAPPShow: value.indexOf("APP") > -1 ? true : false,
            isWXShow: value.indexOf("微信") > -1 ? true : false,
            isWEBShow: value.indexOf("WEB") > -1 ? true : false,
            isMessageShow: value.indexOf("短信") > -1 ? true : false,
        })
    }
    const handleGetForm = form => {
        formEntity.current = form;
    };

    return (
        <SiteModal
            {...props}
            title="编辑推送方案"
            bodyStyle={{ width: '100%', minHeight: '100px' }}
            style={{ top: 200, borderRadius: '20px' }}
            width="1200px"
            destroyOnClose
            cancelText="取消"
            okText="确认"
            onOk={() => onSubmit()}
            confirmLoading={loading}
        >
            <div className={styles.editModal_container}>
                <Form form={form} labelCol={{ span: 4 }}>
                    <Item
                        label="方案名称"
                        name="name"
                        rules={[
                            {
                                required: true,
                                message: '请输入方案名称',
                            },
                        ]}
                    >
                        <Input placeholder="请输入方案名称" />
                    </Item>
                    <Item
                        label="是否开启"
                        name="isStart"
                        initialValue="开启"
                    >
                        <Select >
                            <Option value="开启">开启</Option>
                            <Option value="关闭">关闭</Option>
                        </Select>
                    </Item>
                    <Item
                        label="推送人"
                        name="to_person"

                    >
                        <VisibleRoleModal/>
                    </Item>
                    <Item
                        label="定时计划"
                        name="push_plan"
                    >
                       <VisibleIISAgentConfig/>
                    </Item>
                    <Item
                        label="推送方式"
                        name="params"
                    >
                        <Checkbox.Group
                            options={plainOptions}
                            onChange={onTypeChange}

                        />
                    </Item>
                    <div className={styles.push_trench}>
                        {
                            currentTrench.isAPPShow && (
                                <div className={styles.trench_card}>
                                    <div className={styles.card_title}>
                                        <div className={styles.lable}>APP</div>
                                    </div>
                                    <div className={styles.card_body}>
                                        <Item
                                            label="模板"
                                            name="app_template"
                                        >
                                            <Select defaultValue={"开启"}>
                                                <Option value="开启">开启</Option>
                                                <Option value="关闭">关闭</Option>
                                            </Select>
                                        </Item>
                                        <Item
                                            label="功能路径"
                                            name="app_path"
                                        >
                                            <Input placeholder="请输入功能路径" />
                                        </Item>
                                    </div>
                                </div>
                            )
                        }
                        {
                            currentTrench.isWXShow && (
                                <div className={styles.trench_card}>
                                    <div className={styles.card_title}>
                                        <div className={styles.lable}>微信</div>
                                    </div>
                                    <div className={styles.card_body}>
                                        <Item
                                            label="模板"
                                            name="wx_template"
                                        >
                                            <Select defaultValue={"开启"}>
                                                <Option value="开启">开启</Option>
                                                <Option value="关闭">关闭</Option>
                                            </Select>
                                        </Item>
                                        <Item
                                            label="H5路由"
                                            name="h5_path"
                                        >
                                            <Input placeholder="请输入功能路径" />
                                        </Item>
                                        <Item
                                            label="小程序路由"
                                            name="miniprogram_path"
                                        >
                                            <Input placeholder="请输入功能路径" />
                                        </Item>
                                    </div>
                                </div>
                            )
                        }
                        {
                            currentTrench.isWEBShow && (
                                <div className={styles.trench_card}>
                                    <div className={styles.card_title}>
                                        <div className={styles.lable}>WEB</div>
                                    </div>
                                    <div className={styles.card_body}>
                                        <Item
                                            label="模板"
                                            name="web_template"
                                        >
                                            <Select defaultValue={"开启"}>
                                                <Option value="开启">开启</Option>
                                                <Option value="关闭">关闭</Option>
                                            </Select>
                                        </Item>
                                        <Item
                                            label="功能路径"
                                            name="web_path"
                                        >
                                            <Input placeholder="请输入功能路径" />
                                        </Item>
                                    </div>
                                </div>
                            )
                        }
                        
                        {
                            currentTrench.isMessageShow && (
                                <div className={styles.trench_card}>
                                    <div className={styles.card_title}>
                                        <div className={styles.lable}>短信推送</div>
                                    </div>
                                    <div className={styles.card_body}>
                                        <Item
                                            label="模板"
                                            name="message_template"
                                        >
                                            <Select defaultValue={"开启"}>
                                                <Option value="开启">开启</Option>
                                                <Option value="关闭">关闭</Option>
                                            </Select>
                                        </Item>
                                    </div>
                                </div>
                            )
                        }
                    </div>
                </Form>
            </div>

        </SiteModal>
    )
}
export default EditModal;